@@ -277,7 +277,7 @@ shishi_aprep_enc_part_add (Shishi * handle,
   char *buf;
   size_t buflen;
   char *der;
-  int derlen = BUFSIZ;
+  size_t derlen;
   Shishi_key *key;
 
   res = shishi_encticketpart_get_key (handle, encticketpart, &key);
@@ -381,7 +381,7 @@ shishi_aprep_decrypt (Shishi * handle,
   int i;
   char *buf;
   size_t buflen;
-  char cipher[BUFSIZ];
+  char *cipher;
   size_t cipherlen;
   int etype;
 
@@ -392,14 +392,14 @@ shishi_aprep_decrypt (Shishi * handle,
   if (etype != shishi_key_type (key))
     return SHISHI_APREP_BAD_KEYTYPE;
 
-  cipherlen = BUFSIZ;
-  res = shishi_asn1_field (handle, aprep, cipher, &cipherlen,
-			   "enc-part.cipher");
+  res = shishi_asn1_read2 (handle, aprep, "enc-part.cipher",
+			   &cipher, &cipherlen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_decrypt (handle, key, keyusage, cipher, cipherlen,
 			&buf, &buflen);
+  free (cipher);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle,
