@@ -350,11 +350,12 @@ shishi_apreq_set_authenticator (Shishi * handle,
  * shishi_apreq_add_authenticator:
  * @handle: shishi handle as allocated by shishi_init().
  * @apreq: AP-REQ to add authenticator field to.
- * @enckdcreppart: ticket information where the key is taken from.
+ * @key: key to to use for encryption.
+ * @keyusage: kerberos key usage value to use in encryption.
  * @authenticator: authenticator as allocated by shishi_authenticator().
  *
- * Encrypts DER encoded authenticator using key from ticket and store
- * it in the AP-REQ.
+ * Encrypts DER encoded authenticator using key and store it in the
+ * AP-REQ.
  *
  * Return value: Returns SHISHI_OK iff successful.
  **/
@@ -410,35 +411,35 @@ shishi_apreq_set_ticket (Shishi * handle, Shishi_asn1 apreq,
 {
   int res;
   char *format;
-  unsigned char buf[BUFSIZ];
-  int buflen;
+  char *buf;
+  size_t buflen;
   int i, n;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "tkt-vno", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "tkt-vno", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, apreq, "ticket.tkt-vno", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "realm", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "realm", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, apreq, "ticket.realm", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "sname.name-type", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "sname.name-type", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, apreq, "ticket.sname.name-type",
 			   buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
@@ -454,9 +455,8 @@ shishi_apreq_set_ticket (Shishi * handle, Shishi_asn1 apreq,
       if (res != SHISHI_OK)
 	return res;
 
-      buflen = BUFSIZ;
       asprintf (&format, "sname.name-string.?%d", i);
-      res = shishi_asn1_read (handle, ticket, format, buf, &buflen);
+      res = shishi_asn1_read2 (handle, ticket, format, &buf, &buflen);
       free (format);
       if (res != SHISHI_OK)
 	return res;
@@ -464,40 +464,43 @@ shishi_apreq_set_ticket (Shishi * handle, Shishi_asn1 apreq,
       asprintf (&format, "ticket.sname.name-string.?%d", i);
       res = shishi_asn1_write (handle, apreq, format, buf, buflen);
       free (format);
+      free (buf);
       if (res != SHISHI_OK)
 	return res;
     }
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "enc-part.etype", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "enc-part.etype", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, apreq, "ticket.enc-part.etype",
 			   buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "enc-part.kvno", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "enc-part.kvno", &buf, &buflen);
   if (res != SHISHI_OK && res != SHISHI_ASN1_NO_ELEMENT)
     return res;
 
   if (res == SHISHI_ASN1_NO_ELEMENT)
     res = shishi_asn1_write (handle, apreq, "ticket.enc-part.kvno", NULL, 0);
   else
-    res = shishi_asn1_write (handle, apreq, "ticket.enc-part.kvno",
-			     buf, buflen);
+    {
+      res = shishi_asn1_write (handle, apreq, "ticket.enc-part.kvno",
+			       buf, buflen);
+      free (buf);
+    }
   if (res != SHISHI_OK)
     return res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "enc-part.cipher", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "enc-part.cipher", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, apreq, "ticket.enc-part.cipher",
 			   buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
@@ -581,7 +584,7 @@ shishi_apreq_get_authenticator_etype (Shishi * handle,
 /**
  * shishi_apreq_get_ticket:
  * @handle: shishi handle as allocated by shishi_init().
- * @kdcrep: AP-REQ variable to get ticket from.
+ * @apreq: AP-REQ variable to get ticket from.
  * @ticket: output variable to hold extracted ticket.
  *
  * Extract ticket from AP-REQ.
@@ -592,9 +595,9 @@ int
 shishi_apreq_get_ticket (Shishi * handle,
 			 Shishi_asn1 apreq, Shishi_asn1 * ticket)
 {
-  unsigned char buf[BUFSIZ];
+  char *buf;
   char *format;
-  int buflen;
+  size_t buflen;
   int res;
   int i, n;
 
@@ -604,31 +607,31 @@ shishi_apreq_get_ticket (Shishi * handle,
   if (!*ticket)
     return SHISHI_ASN1_ERROR;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, apreq, "ticket.tkt-vno", buf, &buflen);
+  res = shishi_asn1_read2 (handle, apreq, "ticket.tkt-vno", &buf, &buflen);
   if (res != SHISHI_OK)
     goto error;
 
   res = shishi_asn1_write (handle, *ticket, "tkt-vno", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     goto error;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, apreq, "ticket.realm", buf, &buflen);
+  res = shishi_asn1_read2 (handle, apreq, "ticket.realm", &buf, &buflen);
   if (res != SHISHI_OK)
     goto error;
 
   res = shishi_asn1_write (handle, *ticket, "realm", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     goto error;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, apreq, "ticket.sname.name-type",
-			  buf, &buflen);
+  res = shishi_asn1_read2 (handle, apreq, "ticket.sname.name-type",
+			   &buf, &buflen);
   if (res != SHISHI_OK)
     goto error;
 
   res = shishi_asn1_write (handle, *ticket, "sname.name-type", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     goto error;
 
@@ -644,9 +647,8 @@ shishi_apreq_get_ticket (Shishi * handle,
       if (res != SHISHI_OK)
 	goto error;
 
-      buflen = BUFSIZ;
       asprintf (&format, "ticket.sname.name-string.?%d", i);
-      res = shishi_asn1_read (handle, apreq, format, buf, &buflen);
+      res = shishi_asn1_read2 (handle, apreq, format, &buf, &buflen);
       free (format);
       if (res != SHISHI_OK)
 	goto error;
@@ -654,40 +656,43 @@ shishi_apreq_get_ticket (Shishi * handle,
       asprintf (&format, "sname.name-string.?%d", i);
       res = shishi_asn1_write (handle, *ticket, format, buf, buflen);
       free (format);
+      free (buf);
       if (res != SHISHI_OK)
 	goto error;
     }
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, apreq, "ticket.enc-part.etype",
-			  buf, &buflen);
+  res = shishi_asn1_read2 (handle, apreq, "ticket.enc-part.etype",
+			   &buf, &buflen);
   if (res != SHISHI_OK)
     goto error;
 
   res = shishi_asn1_write (handle, *ticket, "enc-part.etype", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     goto error;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, apreq, "ticket.enc-part.kvno",
-			  buf, &buflen);
+  res = shishi_asn1_read2 (handle, apreq, "ticket.enc-part.kvno",
+			   &buf, &buflen);
   if (res != SHISHI_OK && res != SHISHI_ASN1_NO_ELEMENT)
     goto error;
 
   if (res == SHISHI_ASN1_NO_ELEMENT)
     res = shishi_asn1_write (handle, *ticket, "enc-part.kvno", NULL, 0);
   else
-    res = shishi_asn1_write (handle, *ticket, "enc-part.kvno", buf, buflen);
+    {
+      res = shishi_asn1_write (handle, *ticket, "enc-part.kvno", buf, buflen);
+      free (buf);
+    }
   if (res != SHISHI_OK)
     goto error;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, apreq, "ticket.enc-part.cipher",
-			  buf, &buflen);
+  res = shishi_asn1_read2 (handle, apreq, "ticket.enc-part.cipher",
+			   &buf, &buflen);
   if (res != SHISHI_OK)
     goto error;
 
   res = shishi_asn1_write (handle, *ticket, "enc-part.cipher", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     goto error;
 
@@ -708,8 +713,8 @@ shishi_apreq_decrypt (Shishi * handle,
   int i;
   char *buf;
   size_t buflen;
-  char cipher[BUFSIZ];
-  int cipherlen;
+  char *cipher;
+  size_t cipherlen;
   int etype;
 
   res = shishi_apreq_get_authenticator_etype (handle, apreq, &etype);
@@ -719,15 +724,14 @@ shishi_apreq_decrypt (Shishi * handle,
   if (etype != shishi_key_type (key))
     return SHISHI_APREQ_BAD_KEYTYPE;
 
-  cipherlen = BUFSIZ;
-  res = shishi_asn1_field (handle, apreq, cipher, &cipherlen,
-			   "authenticator.cipher");
+  res = shishi_asn1_read2 (handle, apreq, "authenticator.cipher",
+			   &cipher, &cipherlen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_decrypt (handle, key, keyusage,
 			cipher, cipherlen, &buf, &buflen);
-
+  free (cipher);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle,
