@@ -279,7 +279,7 @@ shishi_authenticator_set_crealm (Shishi * handle,
  * @authenticator: authenticator as allocated by shishi_authenticator().
  * @name_type: type of principial, see Shishi_name_type, usually
  *             SHISHI_NT_UNKNOWN.
- * @principal: input array with principal name.
+ * @cname: input array with principal name.
  *
  * Set principal field in authenticator to specified value.
  *
@@ -304,8 +304,8 @@ shishi_authenticator_set_cname (Shishi * handle,
 /**
  * shishi_authenticator_client_set:
  * @handle: shishi handle as allocated by shishi_init().
- * @kdcrep: Authenticator to set client name field in.
- * @name: zero-terminated string with principal name on RFC 1964 form.
+ * @authenticator: Authenticator to set client name field in.
+ * @client: zero-terminated string with principal name on RFC 1964 form.
  *
  * Set the client name field in the Authenticator.
  *
@@ -333,7 +333,7 @@ shishi_authenticator_ctime_get (Shishi * handle,
   int res;
 
   len = GENERALIZEDTIME_TIME_LEN + 1;
-  res = shishi_asn1_field (handle, authenticator, ctime, &len, "ctime");
+  res = shishi_asn1_read (handle, authenticator, "ctime", ctime, &len);
   if (res == SHISHI_OK && len == GENERALIZEDTIME_TIME_LEN)
     ctime[len] = '\0';
 
@@ -380,7 +380,7 @@ shishi_authenticator_cusec_get (Shishi * handle,
 {
   int res;
 
-  res = shishi_asn1_read_integer (handle, authenticator, "cusec", cusec);
+  res = shishi_asn1_read_uint32 (handle, authenticator, "cusec", cusec);
   if (res != SHISHI_OK)
     return res;
 
@@ -403,7 +403,7 @@ shishi_authenticator_cusec_set (Shishi * handle,
 {
   int res;
 
-  res = shishi_asn1_write_integer (handle, authenticator, "cusec", cusec);
+  res = shishi_asn1_write_uint32 (handle, authenticator, "cusec", cusec);
   if (res != SHISHI_OK)
     return res;
 
@@ -471,8 +471,8 @@ shishi_authenticator_cksum (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  res = shishi_asn1_field (handle, authenticator, cksum, cksumlen,
-			   "cksum.checksum");
+  res = shishi_asn1_read (handle, authenticator, "cksum.checksum",
+			  cksum, cksumlen);
   if (res != SHISHI_OK)
     return res;
 
@@ -520,7 +520,8 @@ shishi_authenticator_set_cksum (Shishi * handle,
  * shishi_authenticator_add_cksum:
  * @handle: shishi handle as allocated by shishi_init().
  * @authenticator: authenticator as allocated by shishi_authenticator().
- * @enckdcreppart: ticket information where the key is taken from.
+ * @key: key to to use for encryption.
+ * @keyusage: kerberos key usage value to use in encryption.
  * @data: input array with data to calculate checksum on.
  * @datalen: size of input array with data to calculate checksum on.
  *
@@ -669,7 +670,7 @@ shishi_authenticator_authorizationdata (Shishi * handle,
     return res;
 
   asprintf (&format, "authorization-data.?%d.ad-data", i);
-  res = shishi_asn1_field (handle, authenticator, addata, addatalen, format);
+  res = shishi_asn1_read (handle, authenticator, format, addata, addatalen);
   free (format);
   if (res != SHISHI_OK)
     return res;
