@@ -77,7 +77,6 @@ raw_des_verify (Shishi * handle, int algo, char *out, int *outlen)
   char incoming[MAX_HASH_LEN];
   char computed[MAX_HASH_LEN];
   int hlen;
-  int rc;
 
   switch (algo)
     {
@@ -601,9 +600,6 @@ des_string_to_key (Shishi * handle,
 
     }
 
-  if (saltlen < 0)
-    saltlen = 0;
-
   odd = 1;
   n_s = stringlen + saltlen;
   if ((n_s % 8) != 0)
@@ -830,7 +826,7 @@ des_md5_checksum (Shishi * handle,
 		       SHISHI_DES_CBC_MD5);
 }
 
-int
+static int
 gss_des_checksum (Shishi * handle,
 		  Shishi_key * key,
 		  int keyusage,
@@ -839,8 +835,6 @@ gss_des_checksum (Shishi * handle,
 		  char **out, size_t * outlen)
 {
 #ifdef USE_GCRYPT
-  char buffer[BUFSIZ];
-  int buflen;
   char *keyp;
   char *p;
   int i;
