@@ -448,7 +448,6 @@ simplified_dencrypt (Shishi * handle,
   struct CBC_CTX(struct des_ctx, DES_BLOCK_SIZE) des;
   struct CBC_CTX(struct des3_ctx, DES3_BLOCK_SIZE) des3;
   struct CBC_CTS_CTX(struct aes_ctx, AES_BLOCK_SIZE) aes;
-  void *p;
   int rc;
 
   *outlen = inlen;
@@ -613,7 +612,6 @@ simplified_decrypt (Shishi * handle,
       Shishi_key *privacykey = NULL, *integritykey = NULL;
       int blen = shishi_cipher_blocksize (shishi_key_type (key));
       size_t hlen = 20; /* XXX only works for SHA-1 */
-      size_t len;
 
       res = simplified_derivekey (handle, key, keyusage,
 				  SHISHI_DERIVEKEYMODE_PRIVACY, &privacykey);
@@ -664,7 +662,6 @@ simplified_checksum (Shishi * handle,
 		     char *in, size_t inlen, char **out, size_t * outlen)
 {
   Shishi_key *checksumkey;
-  size_t hlen = 20; /* XXX only works for SHA-1 */
   int cksumlen = shishi_checksum_cksumlen (cksumtype);
   int res;
 
@@ -1921,9 +1918,7 @@ shishi_n_fold (Shishi * handle,
 /**
  * shishi_dr:
  * @handle: shishi handle as allocated by shishi_init().
- * @etype: cryptographic encryption type, see Shishi_etype.
  * @key: input array with cryptographic key to use.
- * @keylen: size of input array with cryptographic key.
  * @constant: input array with the constant string.
  * @constantlen: size of input array with the constant string.
  * @derivedrandom: output array with derived random data.
@@ -1944,7 +1939,7 @@ shishi_dr (Shishi * handle,
   char *cipher;
   char plaintext[MAX_DR_CONSTANT];
   char nfoldconstant[MAX_DR_CONSTANT];
-  int blocksize = shishi_cipher_blocksize (shishi_key_type (key));
+  size_t blocksize = shishi_cipher_blocksize (shishi_key_type (key));
   size_t totlen, cipherlen;
   int res;
 
@@ -2024,13 +2019,10 @@ shishi_dr (Shishi * handle,
 /**
  * shishi_dk:
  * @handle: shishi handle as allocated by shishi_init().
- * @etype: cryptographic encryption type, see Shishi_etype.
- * @key: input array with cryptographic key to use.
- * @keylen: size of input array with cryptographic key.
+ * @key: input cryptographic key to use.
  * @constant: input array with the constant string.
  * @constantlen: size of input array with the constant string.
- * @derivedkey: output array with derived key.
- * @derivedkeylen: size of output array with derived key.
+ * @derivedkey: pointer to derived key (allocated by caller).
  *
  * Derive a key from a key and a constant thusly:
  * DK(KEY, CONSTANT) = SHISHI_RANDOM-TO-KEY(SHISHI_DR(KEY, CONSTANT)).
