@@ -68,10 +68,7 @@ shishi_encasreppart (Shishi * handle)
  * shishi_enckdcreppart_get_key:
  * @handle: shishi handle as allocated by shishi_init().
  * @enckdcreppart: input EncKDCRepPart variable.
- * @keytype: output variable that holds key type.
- * @keyvalue: output array with key.
- * @keyvalue_len: on input, maximum size of output array with key,
- *                on output, holds the actual size of output array with key.
+ * @key: newly allocated encryption key handle.
  *
  * Extract the key to use with the ticket sent in the KDC-REP
  * associated with the EndKDCRepPart input variable.
@@ -83,8 +80,8 @@ shishi_enckdcreppart_get_key (Shishi * handle,
 			      Shishi_asn1 enckdcreppart, Shishi_key ** key)
 {
   int res;
-  char buf[BUFSIZ];
-  int buflen;
+  char *buf;
+  size_t buflen;
   int32_t keytype;
 
   res = shishi_asn1_read_int32 (handle, enckdcreppart,
@@ -92,13 +89,13 @@ shishi_enckdcreppart_get_key (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_field (handle, enckdcreppart, buf, &buflen,
-			   "key.keyvalue");
+  res = shishi_asn1_read2 (handle, enckdcreppart, "key.keyvalue",
+			   &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_key_from_value (handle, keytype, buf, key);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
@@ -198,59 +195,64 @@ shishi_enckdcreppart_populate_encticketpart (Shishi * handle,
 					     Shishi_asn1 enckdcreppart,
 					     Shishi_asn1 encticketpart)
 {
-  unsigned char buf[BUFSIZ];
-  int buflen;
+  char *buf;
+  size_t buflen;
   int res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, encticketpart, "flags", buf, &buflen);
+  res = shishi_asn1_read2 (handle, encticketpart, "flags", &buf, &buflen);
   if (res != SHISHI_OK)
     return SHISHI_ASN1_ERROR;
 
   res = shishi_asn1_write (handle, enckdcreppart, "flags", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return SHISHI_ASN1_ERROR;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, encticketpart, "authtime", buf, &buflen);
+  res = shishi_asn1_read2 (handle, encticketpart, "authtime", &buf, &buflen);
   if (res != SHISHI_OK)
     return SHISHI_ASN1_ERROR;
 
   res = shishi_asn1_write (handle, enckdcreppart, "authtime", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return SHISHI_ASN1_ERROR;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, encticketpart, "starttime", buf, &buflen);
+  res = shishi_asn1_read2 (handle, encticketpart, "starttime", &buf, &buflen);
   if (res != SHISHI_OK && res != SHISHI_ASN1_NO_ELEMENT)
     return SHISHI_ASN1_ERROR;
 
   if (res == SHISHI_ASN1_NO_ELEMENT)
     res = shishi_asn1_write (handle, enckdcreppart, "starttime", NULL, 0);
   else
-    res = shishi_asn1_write (handle, enckdcreppart, "starttime", buf, buflen);
+    {
+      res = shishi_asn1_write (handle, enckdcreppart, "starttime",
+			       buf, buflen);
+      free (buf);
+    }
   if (res != SHISHI_OK)
     return SHISHI_ASN1_ERROR;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, encticketpart, "endtime", buf, &buflen);
+  res = shishi_asn1_read2 (handle, encticketpart, "endtime", &buf, &buflen);
   if (res != SHISHI_OK)
     return SHISHI_ASN1_ERROR;
 
   res = shishi_asn1_write (handle, enckdcreppart, "endtime", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return SHISHI_ASN1_ERROR;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, encticketpart, "renew-till", buf, &buflen);
+  res = shishi_asn1_read2 (handle, encticketpart, "renew-till", &buf, &buflen);
   if (res != SHISHI_OK && res != SHISHI_ASN1_NO_ELEMENT)
     return SHISHI_ASN1_ERROR;
 
   if (res == SHISHI_ASN1_NO_ELEMENT)
     res = shishi_asn1_write (handle, enckdcreppart, "renew-till", NULL, 0);
   else
-    res = shishi_asn1_write (handle, enckdcreppart,
-			     "renew-till", buf, buflen);
+    {
+      res = shishi_asn1_write (handle, enckdcreppart,
+			       "renew-till", buf, buflen);
+      free (buf);
+    }
   if (res != SHISHI_OK)
     return SHISHI_ASN1_ERROR;
 
