@@ -87,10 +87,7 @@ shishi_encticketpart_get_enc_part_etype (Shishi * handle,
  * shishi_encticketpart_get_key:
  * @handle: shishi handle as allocated by shishi_init().
  * @encticketpart: input EncTicketPart variable.
- * @keytype: output variable that holds key type.
- * @keyvalue: output array with key.
- * @keyvalue_len: on input, maximum size of output array with key,
- *                on output, holds the actual size of output array with key.
+ * @key: newly allocated key.
  *
  * Extract the session key in the Ticket.
  *
@@ -101,8 +98,8 @@ shishi_encticketpart_get_key (Shishi * handle,
 			      Shishi_asn1 encticketpart, Shishi_key ** key)
 {
   int res;
-  char buf[BUFSIZ];
-  int buflen;
+  char *buf;
+  size_t buflen;
   int32_t keytype;
 
   res = shishi_asn1_read_int32 (handle, encticketpart,
@@ -110,13 +107,13 @@ shishi_encticketpart_get_key (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_field (handle, encticketpart, buf, &buflen,
-			   "key.keyvalue");
+  res = shishi_asn1_read2 (handle, encticketpart, "key.keyvalue",
+			   &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_key_from_value (handle, keytype, buf, key);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
@@ -139,17 +136,15 @@ shishi_encticketpart_key_set (Shishi * handle,
 			      Shishi_asn1 encticketpart, Shishi_key * key)
 {
   int res;
-  char buf[BUFSIZ];
   int keytype;
 
   keytype = shishi_key_type (key);
-  sprintf (buf, "%d", keytype);
-  res = shishi_asn1_write (handle, encticketpart, "key.keytype", buf, 0);
+  res = shishi_asn1_write_uint32 (handle, encticketpart,
+				  "key.keytype", keytype);
   if (res != SHISHI_OK)
     return res;
 
-  res = shishi_asn1_write (handle, encticketpart,
-			   "key.keyvalue",
+  res = shishi_asn1_write (handle, encticketpart, "key.keyvalue",
 			   shishi_key_value (key), shishi_key_length (key));
   if (res != SHISHI_OK)
     return res;
@@ -172,10 +167,8 @@ shishi_encticketpart_flags_set (Shishi * handle,
 				Shishi_asn1 encticketpart, int flags)
 {
   int res;
-  char buf[BUFSIZ];
 
-  sprintf (buf, "%d", flags);
-  res = shishi_asn1_write (handle, encticketpart, "flags", buf, 0);
+  res = shishi_asn1_write_uint32 (handle, encticketpart, "flags", flags);
   if (res != SHISHI_OK)
     return res;
 
@@ -224,11 +217,9 @@ shishi_encticketpart_cname_set (Shishi * handle,
 				const char *principal)
 {
   int res;
-  char buf[BUFSIZ];
 
-  sprintf (buf, "%d", name_type);
-
-  res = shishi_asn1_write (handle, encticketpart, "cname.name-type", buf, 0);
+  res = shishi_asn1_write_uint32 (handle, encticketpart,
+				  "cname.name-type", name_type);
   if (res != SHISHI_OK)
     return res;
 
@@ -270,11 +261,9 @@ shishi_encticketpart_transited_set (Shishi * handle,
 				    char *trdata, size_t trdatalen)
 {
   int res;
-  char buf[BUFSIZ];
 
-  sprintf (buf, "%d", trtype);
-  res = shishi_asn1_write (handle, encticketpart,
-			   "transited.tr-type", buf, 0);
+  res = shishi_asn1_write_uint32 (handle, encticketpart,
+				  "transited.tr-type", trtype);
   if (res != SHISHI_OK)
     return res;
 
@@ -341,8 +330,8 @@ shishi_encticketpart_authtime (Shishi * handle,
 			       Shishi_asn1 encticketpart,
 			       char *authtime, int *authtimelen)
 {
-  return shishi_asn1_field (handle, encticketpart, authtime, authtimelen,
-			    "authtime");
+  return shishi_asn1_read (handle, encticketpart, "authtime",
+			   authtime, authtimelen);
 }
 
 time_t
