@@ -1,4 +1,4 @@
-/* hostkeys.c	Functions for managing keys stored in files.
+/* hostkeys.c	Functions for managing hostkeys stored in files.
  * Copyright (C) 2002, 2003  Simon Josefsson
  *
  * This file is part of Shishi.
@@ -58,85 +58,6 @@ shishi_hostkeys_default_file_set (Shishi * handle, const char *hostkeysfile)
     handle->hostkeysdefaultfile = NULL;
 }
 
-/**
- * shishi_hostkeys_for_serverrealm_in_file
- * @handle: Shishi library handle create by shishi_init().
- * @filename: file to read keys from.
- * @server: server name to get key for.
- * @realm: realm of server to get key for.
- *
- * Return value: Returns the key for specific server and realm, read
- * from the indicated file, or NULL if no key could be found or an
- * error encountered.
- **/
-Shishi_key *
-shishi_hostkeys_for_serverrealm_in_file (Shishi * handle,
-					 const char *filename,
-					 const char *server,
-					 const char *realm)
-{
-  Shishi_key *key = NULL;
-  FILE *fh;
-  int res;
-
-  fh = fopen (filename, "r");
-  if (fh == NULL)
-    return NULL;
-
-  res = SHISHI_OK;
-  while (!feof (fh))
-    {
-      res = shishi_key_parse (handle, fh, &key);
-      if (res != SHISHI_OK || key == NULL)
-	break;
-
-      if (VERBOSENOICE (handle))
-	{
-	  printf ("Read key:\n");
-	  shishi_key_print (handle, stdout, key);
-	}
-
-      if (server == NULL && realm == NULL)
-	break;
-
-      if (server &&
-	  shishi_key_principal (key) &&
-	  strcmp (server, shishi_key_principal (key)) == 0)
-	break;
-
-      if (realm &&
-	  shishi_key_realm (key) &&
-	  strcmp (server, shishi_key_principal (key)) == 0)
-	break;
-
-      shishi_key_done (&key);
-    }
-
-  res = fclose (fh);
-  if (res != 0)
-    return NULL;
-
-  return key;
-}
-
-/**
- * shishi_hostkeys_for_server_in_file
- * @handle: Shishi library handle create by shishi_init().
- * @filename: file to read keys from.
- * @server: server name to get key for.
- *
- * Return value: Returns the key for specific server, read from the
- * indicated file, or NULL if no key could be found or an error
- * encountered.
- **/
-Shishi_key *
-shishi_hostkeys_for_server_in_file (Shishi * handle,
-				    const char *filename, const char *server)
-{
-  return shishi_hostkeys_for_serverrealm_in_file (handle, filename,
-						  server, NULL);
-}
-
 /**
  * shishi_hostkeys_for_server
  * @handle: Shishi library handle create by shishi_init().
@@ -149,8 +70,9 @@ shishi_hostkeys_for_server_in_file (Shishi * handle,
 Shishi_key *
 shishi_hostkeys_for_server (Shishi * handle, const char *server)
 {
-  return shishi_hostkeys_for_server_in_file
-    (handle, shishi_hostkeys_default_file (handle), server);
+  return shishi_keys_for_server_in_file (handle,
+					 shishi_hostkeys_default_file (handle),
+					 server);
 }
 
 /**
@@ -168,15 +90,15 @@ Shishi_key *
 shishi_hostkeys_for_serverrealm (Shishi * handle,
 				 const char *server, const char *realm)
 {
-  return shishi_hostkeys_for_serverrealm_in_file
+  return shishi_keys_for_serverrealm_in_file
     (handle, shishi_hostkeys_default_file (handle), server, realm);
 }
 
 /**
- * shishi_hostkeys_for_localservice
+ * shishi_hostkeys_for_localservicerealm
  * @handle: Shishi library handle create by shishi_init().
  * @service: service to get key for.
- * @realm: realm of server to get key for.
+ * @realm: realm of server to get key for, or NULL for default realm.
  *
  * Return value: Returns the key for the server
  * "SERVICE/HOSTNAME@REALM" (where HOSTNAME is the current system's
@@ -186,22 +108,11 @@ shishi_hostkeys_for_serverrealm (Shishi * handle,
  **/
 Shishi_key *
 shishi_hostkeys_for_localservicerealm (Shishi * handle,
-				       const char *service, const char *realm)
+				       const char *service,
+				       const char *realm)
 {
-  char buf[HOST_NAME_MAX];
-  int ret;
-
-  strcpy (buf, service);
-  strcat (buf, "/");
-
-  ret = gethostname (&buf[strlen (service) + 1],
-		     sizeof (buf) - strlen (service) - 1);
-  buf[sizeof (buf) - 1] = '\0';
-
-  if (ret != 0)
-    strcpy (&buf[strlen (service) + 1], "localhost");
-
-  return shishi_hostkeys_for_serverrealm (handle, buf, realm);
+  return shishi_keys_for_localservicerealm_in_file
+    (handle, shishi_hostkeys_default_file (handle), service, realm);
 }
 
 /**
