@@ -24,7 +24,7 @@
 /**
  * shishi_as_derive_salt:
  * @handle: shishi handle as allocated by shishi_init().
- * @asrep: input AS-REP variable.
+ * @asreq: input AS-REQ variable.
  * @asrep: input AS-REP variable.
  * @salt: output array with salt.
  * @saltlen: on input, maximum size of output array with salt, on output,
@@ -112,9 +112,10 @@ shishi_kdcreq_sendrecv (Shishi * handle, Shishi_asn1 kdcreq,
 			Shishi_asn1 * kdcrep)
 {
   char *der;
-  int der_len, out_len;
-  char buffer[BUFSIZ];		/* XXX dynamically allocate this? */
-  char realm[BUFSIZ];		/* XXX dynamically allocate this */
+  int der_len;
+  size_t buflen;
+  char *buffer;
+  char *realm;
   int realmlen;
   int res;
 
@@ -126,40 +127,40 @@ shishi_kdcreq_sendrecv (Shishi * handle, Shishi_asn1 kdcreq,
       return res;
     }
 
-  realmlen = sizeof (realm);
-  res = shishi_asn1_field (handle, kdcreq, realm, &realmlen,
-			   "req-body.realm");
+  res = shishi_asn1_read2 (handle, kdcreq, "req-body.realm",
+			   &realm, &realmlen);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle, "Could not get realm: %s\n",
 			   shishi_strerror_details (handle));
       return res;
     }
+  realm = xrealloc (realm, realmlen + 1);
   realm[realmlen] = '\0';
 
-  out_len = sizeof (buffer);
-  res = shishi_kdc_sendrecv (handle, realm, der, der_len, buffer, &out_len);
+  res = shishi_kdc_sendrecv (handle, realm, der, der_len, &buffer, &buflen);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle, "Could not send to KDC: %s\n",
 			   shishi_strerror_details (handle));
       return res;
     }
+  free (realm);
   free (der);
 
   if (VERBOSEASN1 (handle))
-    printf ("received %d bytes\n", out_len);
+    printf ("received %d bytes\n", buflen);
 
-  *kdcrep = shishi_der2asn1_asrep (handle, buffer, out_len);
+  *kdcrep = shishi_der2asn1_asrep (handle, buffer, buflen);
   if (*kdcrep == NULL)
     {
-      *kdcrep = shishi_der2asn1_tgsrep (handle, buffer, out_len);
+      *kdcrep = shishi_der2asn1_tgsrep (handle, buffer, buflen);
       if (*kdcrep == NULL)
 	{
-	  *kdcrep = shishi_der2asn1_kdcrep (handle, buffer, out_len);
+	  *kdcrep = shishi_der2asn1_kdcrep (handle, buffer, buflen);
 	  if (*kdcrep == NULL)
 	    {
-	      *kdcrep = shishi_der2asn1_krberror (handle, buffer, out_len);
+	      *kdcrep = shishi_der2asn1_krberror (handle, buffer, buflen);
 	      if (*kdcrep == NULL)
 		{
 		  shishi_error_printf
@@ -178,6 +179,7 @@ shishi_kdcreq_sendrecv (Shishi * handle, Shishi_asn1 kdcreq,
 	    }
 	}
     }
+  free (buffer);
 
   return SHISHI_OK;
 }
@@ -185,7 +187,7 @@ shishi_kdcreq_sendrecv (Shishi * handle, Shishi_asn1 kdcreq,
 /**
  * shishi_kdc_copy_crealm:
  * @handle: shishi handle as allocated by shishi_init().
- * @kdcreq: KDC-REQ to read crealm from.
+ * @kdcrep: KDC-REP to read crealm from.
  * @encticketpart: EncTicketPart to set crealm in.
  *
  * Set crealm in KDC-REP to value in EncTicketPart.
@@ -194,20 +196,23 @@ shishi_kdcreq_sendrecv (Shishi * handle, Shishi_asn1 kdcreq,
  **/
 int
 shishi_kdc_copy_crealm (Shishi * handle,
-			Shishi_asn1 kdcrep, Shishi_asn1 encticketpart)
+			Shishi_asn1 kdcrep,
+			Shishi_asn1 encticketpart)
 {
-  unsigned char buf[BUFSIZ];
-  int buflen;
+  char *buf;
+  size_t buflen;
   int res;
 
+#if 0
   buf[0] = '\0';		/* XXX if crealm is empty, buflen == 0 which
 				   causes libtasn1 to strlen(buf)... */
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, encticketpart, "crealm", buf, &buflen);
+#endif
+  res = shishi_asn1_read2 (handle, encticketpart, "crealm", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, kdcrep, "crealm", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
@@ -217,8 +222,8 @@ shishi_kdc_copy_crealm (Shishi * handle,
 /**
  * shishi_as_check_crealm:
  * @handle: shishi handle as allocated by shishi_init().
- * @kdcreq: AS-REQ to compare realm field in.
- * @kdcrep: AS-REP to compare realm field in.
+ * @asreq: AS-REQ to compare realm field in.
+ * @asrep: AS-REP to compare realm field in.
  *
  * Verify that AS-REQ.req-body.realm and AS-REP.crealm fields matches.
  * This is one of the steps that has to be performed when processing a
@@ -230,12 +235,12 @@ shishi_kdc_copy_crealm (Shishi * handle,
 int
 shishi_as_check_crealm (Shishi * handle, Shishi_asn1 asreq, Shishi_asn1 asrep)
 {
-  char reqrealm[BUFSIZ], reprealm[BUFSIZ];
-  int reqrealmlen = BUFSIZ, reprealmlen = BUFSIZ;
+  char *reqrealm, *reprealm;
+  size_t reqrealmlen, reprealmlen;
   int res;
 
-  res = shishi_asn1_read (handle, asreq, "req-body.realm",
-			  reqrealm, &reqrealmlen);
+  res = shishi_asn1_read2 (handle, asreq, "req-body.realm",
+			   &reqrealm, &reqrealmlen);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle, "Could not read request realm: %s\n",
@@ -243,7 +248,7 @@ shishi_as_check_crealm (Shishi * handle, Shishi_asn1 asreq, Shishi_asn1 asrep)
       return res;
     }
 
-  res = shishi_asn1_read (handle, asrep, "crealm", reprealm, &reprealmlen);
+  res = shishi_asn1_read2 (handle, asrep, "crealm", &reprealm, &reprealmlen);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle, "Could not read reply realm: %s\n",
@@ -260,16 +265,21 @@ shishi_as_check_crealm (Shishi * handle, Shishi_asn1 asreq, Shishi_asn1 asrep)
       printf ("reply realm: %s\n", reprealm);
     }
 
-  if (strcmp (reqrealm, reprealm) != 0)
+  res = strcmp (reqrealm, reprealm) != 0;
+
+  free (reqrealm);
+  free (reprealm);
+
+  if (res)
     return SHISHI_REALM_MISMATCH;
 
   return SHISHI_OK;
 }
 
 /**
- * shishi_kdc_copy_crealm:
+ * shishi_kdc_copy_cname:
  * @handle: shishi handle as allocated by shishi_init().
- * @kdcreq: KDC-REQ to read cname from.
+ * @kdcrep: KDC-REQ to read cname from.
  * @encticketpart: EncTicketPart to set cname in.
  *
  * Set cname in KDC-REP to value in EncTicketPart.
@@ -280,19 +290,19 @@ int
 shishi_kdc_copy_cname (Shishi * handle,
 		       Shishi_asn1 kdcrep, Shishi_asn1 encticketpart)
 {
-  unsigned char buf[BUFSIZ];
-  char format[BUFSIZ];
-  int buflen;
+  char *buf;
+  char *format;
+  size_t buflen;
   int res;
   int i, n;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, encticketpart,
-			  "cname.name-type", buf, &buflen);
+  res = shishi_asn1_read2 (handle, encticketpart,
+			  "cname.name-type", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, kdcrep, "cname.name-type", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
@@ -311,14 +321,16 @@ shishi_kdc_copy_cname (Shishi * handle,
       if (res != SHISHI_OK)
 	return res;
 
-      sprintf (format, "cname.name-string.?%d", i);
-      buflen = BUFSIZ;
-      res = shishi_asn1_read (handle, encticketpart, format, buf, &buflen);
+      asprintf (&format, "cname.name-string.?%d", i);
+      res = shishi_asn1_read2 (handle, encticketpart, format, &buf, &buflen);
+      free (format);
       if (res != SHISHI_OK)
 	return res;
 
-      sprintf (format, "cname.name-string.?%d", i);
+      asprintf (&format, "cname.name-string.?%d", i);
       res = shishi_asn1_write (handle, kdcrep, format, buf, buflen);
+      free (format);
+      free (buf);
       if (res != SHISHI_OK)
 	return res;
     }
@@ -329,8 +341,8 @@ shishi_kdc_copy_cname (Shishi * handle,
 /**
  * shishi_as_check_cname:
  * @handle: shishi handle as allocated by shishi_init().
- * @kdcreq: AS-REQ to compare client name field in.
- * @kdcrep: AS-REP to compare client name field in.
+ * @asreq: AS-REQ to compare client name field in.
+ * @asrep: AS-REP to compare client name field in.
  *
  * Verify that AS-REQ.req-body.realm and AS-REP.crealm fields matches.
  * This is one of the steps that has to be performed when processing a
@@ -342,9 +354,9 @@ shishi_kdc_copy_cname (Shishi * handle,
 int
 shishi_as_check_cname (Shishi * handle, Shishi_asn1 asreq, Shishi_asn1 asrep)
 {
-  char reqcname[BUFSIZ], repcname[BUFSIZ];
-  int reqcnamelen, repcnamelen;
-  char format[BUFSIZ];
+  char *reqcname, *repcname;
+  size_t reqcnamelen, repcnamelen;
+  char *format;
   int res;
   int i, j;
 
@@ -365,15 +377,15 @@ shishi_as_check_cname (Shishi * handle, Shishi_asn1 asreq, Shishi_asn1 asrep)
 
   for (i = 1; i <= j; i++)
     {
-      sprintf (format, "req-body.cname.name-string.?%d", i);
-      reqcnamelen = sizeof (reqcname);
-      res = shishi_asn1_read (handle, asreq, format, reqcname, &reqcnamelen);
+      asprintf (&format, "req-body.cname.name-string.?%d", i);
+      res = shishi_asn1_read2 (handle, asreq, format, &reqcname, &reqcnamelen);
+      free (format);
       if (res != SHISHI_OK)
 	return res;
 
-      sprintf (format, "cname.name-string.?%d", i);
-      repcnamelen = sizeof (repcname);
-      res = shishi_asn1_read (handle, asrep, format, repcname, &repcnamelen);
+      asprintf (&format, "cname.name-string.?%d", i);
+      res = shishi_asn1_read2 (handle, asrep, format, &repcname, &repcnamelen);
+      free (format);
       if (res != SHISHI_OK)
 	return res;
 
@@ -385,10 +397,13 @@ shishi_as_check_cname (Shishi * handle, Shishi_asn1 asreq, Shishi_asn1 asrep)
 	  printf ("reply cname %d: %s\n", i, repcname);
 	}
 
-      if (reqcnamelen != repcnamelen)
-	return SHISHI_CNAME_MISMATCH;
+      res = (reqcnamelen != repcnamelen) ||
+	(memcmp (reqcname, repcname, reqcnamelen) != 0);
 
-      if (memcmp (reqcname, repcname, reqcnamelen) != 0)
+      free (reqcname);
+      free (repcname);
+
+      if (res)
 	return SHISHI_CNAME_MISMATCH;
     }
 
@@ -423,52 +438,14 @@ shishi_kdc_copy_nonce (Shishi * handle,
   return SHISHI_OK;
 }
 
-/**
- * shishi_kdc_check_nonce:
- * @handle: shishi handle as allocated by shishi_init().
- * @kdcreq: KDC-REQ to compare nonce field in.
- * @enckdcreppart: Encrypted KDC-REP part to compare nonce field in.
- *
- * Verify that KDC-REQ.req-body.nonce and EncKDCRepPart.nonce fields
- * matches.  This is one of the steps that has to be performed when
- * processing a KDC-REQ and KDC-REP exchange.
- *
- * Return value: Returns SHISHI_OK if successful,
- * SHISHI_NONCE_LENGTH_MISMATCH if the nonces have different lengths
- * (usually indicates that buggy server truncated nonce to 4 bytes),
- * SHISHI_NONCE_MISMATCH if the values differ, or an error code.
- **/
-int
-shishi_kdc_check_nonce (Shishi * handle,
-			Shishi_asn1 kdcreq, Shishi_asn1 enckdcreppart)
+static int
+shishi_kdc_check_nonce_1 (Shishi * handle,
+			  char *reqnonce, size_t reqnoncelen,
+			  char *repnonce, size_t repnoncelen)
 {
-  unsigned char reqnonce[BUFSIZ];
-  unsigned char repnonce[BUFSIZ];
-  int reqnoncelen = BUFSIZ;
-  int repnoncelen = BUFSIZ;
-  int res;
-
-  res = shishi_asn1_read (handle, kdcreq, "req-body.nonce",
-			  reqnonce, &reqnoncelen);
-  if (res != SHISHI_OK)
-    {
-      shishi_error_printf (handle, "Could not read request nonce: %s\n",
-			   shishi_strerror (res));
-      return res;
-    }
-
-  res = shishi_asn1_read (handle, enckdcreppart, "nonce",
-			  repnonce, &repnoncelen);
-  if (res != SHISHI_OK)
-    {
-      shishi_error_printf (handle, "Could not read reply nonce: %s\n",
-			   shishi_strerror (res));
-      return res;
-    }
-
   if (VERBOSEASN1 (handle))
     {
-      int i;
+      size_t i;
 
       printf ("request nonce (len=%d) ", reqnoncelen);
       for (i = 0; i < reqnoncelen; i++)
@@ -510,11 +487,77 @@ shishi_kdc_check_nonce (Shishi * handle,
   return SHISHI_OK;
 }
 
+/**
+ * shishi_kdc_check_nonce:
+ * @handle: shishi handle as allocated by shishi_init().
+ * @kdcreq: KDC-REQ to compare nonce field in.
+ * @enckdcreppart: Encrypted KDC-REP part to compare nonce field in.
+ *
+ * Verify that KDC-REQ.req-body.nonce and EncKDCRepPart.nonce fields
+ * matches.  This is one of the steps that has to be performed when
+ * processing a KDC-REQ and KDC-REP exchange.
+ *
+ * Return value: Returns SHISHI_OK if successful,
+ * SHISHI_NONCE_LENGTH_MISMATCH if the nonces have different lengths
+ * (usually indicates that buggy server truncated nonce to 4 bytes),
+ * SHISHI_NONCE_MISMATCH if the values differ, or an error code.
+ **/
+int
+shishi_kdc_check_nonce (Shishi * handle,
+			Shishi_asn1 kdcreq, Shishi_asn1 enckdcreppart)
+{
+  char *reqnonce;
+  char *repnonce;
+  size_t reqnoncelen, repnoncelen;
+  int res;
+
+  res = shishi_asn1_read2 (handle, kdcreq, "req-body.nonce",
+			   &reqnonce, &reqnoncelen);
+  if (res != SHISHI_OK)
+    {
+      shishi_error_printf (handle, "Could not read request nonce: %s\n",
+			   shishi_strerror (res));
+      return res;
+    }
+
+  res = shishi_asn1_read2 (handle, enckdcreppart, "nonce",
+			   &repnonce, &repnoncelen);
+  if (res != SHISHI_OK)
+    {
+      free (reqnonce);
+      shishi_error_printf (handle, "Could not read reply nonce: %s\n",
+			   shishi_strerror (res));
+      return res;
+    }
+
+  if (VERBOSEASN1 (handle))
+    {
+      size_t i;
+
+      printf ("request nonce (len=%d) ", reqnoncelen);
+      for (i = 0; i < reqnoncelen; i++)
+	printf ("%02X", reqnonce[i]);
+      printf ("\n");
+      printf ("reply nonce (len=%d) ", repnoncelen);
+      for (i = 0; i < repnoncelen; i++)
+	printf ("%02X", repnonce[i]);
+      printf ("\n");
+    }
+
+  res = shishi_kdc_check_nonce_1 (handle, reqnonce, reqnoncelen,
+				  repnonce, repnoncelen);
+
+  free (reqnonce);
+  free (repnonce);
+
+  return res;
+}
+
 /**
  * shishi_tgs_process:
  * @handle: shishi handle as allocated by shishi_init().
- * @kdcreq: input variable that holds the sent KDC-REQ.
- * @kdcrep: input variable that holds the received KDC-REP.
+ * @tgsreq: input variable that holds the sent KDC-REQ.
+ * @tgsrep: input variable that holds the received KDC-REP.
  * @oldenckdcreppart: input variable with EncKDCRepPart used in request.
  * @enckdcreppart: output variable that holds new EncKDCRepPart.
  *
@@ -557,8 +600,8 @@ shishi_tgs_process (Shishi * handle,
 /**
  * shishi_as_process:
  * @handle: shishi handle as allocated by shishi_init().
- * @kdcreq: input variable that holds the sent KDC-REQ.
- * @kdcrep: input variable that holds the received KDC-REP.
+ * @asreq: input variable that holds the sent KDC-REQ.
+ * @asrep: input variable that holds the received KDC-REP.
  * @string: input variable with zero terminated password.
  * @enckdcreppart: output variable that holds new EncKDCRepPart.
  *
@@ -611,9 +654,8 @@ shishi_as_process (Shishi * handle,
  * @handle: shishi handle as allocated by shishi_init().
  * @kdcreq: input variable that holds the sent KDC-REQ.
  * @kdcrep: input variable that holds the received KDC-REP.
- * @keytype: input variable that holds type of key.
  * @key: input array with key to decrypt encrypted part of KDC-REP with.
- * @keylen: size of input array with key.
+ * @keyusage: kereros key usage value.
  * @enckdcreppart: output variable that holds new EncKDCRepPart.
  *
  * Process a KDC client exchange and output decrypted EncKDCRepPart
