@@ -66,7 +66,7 @@ error:
 }
 
 /**
- * shishi_as_rep:
+ * shishi_asrep:
  * @handle: shishi handle as allocated by shishi_init().
  *
  * This function creates a new AS-REP, populated with some default
@@ -81,7 +81,7 @@ shishi_asrep (Shishi * handle)
 }
 
 /**
- * shishi_tgs_rep:
+ * shishi_tgsrep:
  * @handle: shishi handle as allocated by shishi_init().
  *
  * This function creates a new TGS-REP, populated with some default
@@ -309,7 +309,7 @@ shishi_kdcrep_cname_set (Shishi * handle,
  * shishi_kdcrep_client_set:
  * @handle: shishi handle as allocated by shishi_init().
  * @kdcrep: Kdcrep variable to set server name field in.
- * @name: zero-terminated string with principal name on RFC 1964 form.
+ * @client: zero-terminated string with principal name on RFC 1964 form.
  *
  * Set the client name field in the KDC-REP.
  *
@@ -377,9 +377,9 @@ int
 shishi_kdcrep_get_ticket (Shishi * handle,
 			  Shishi_asn1 kdcrep, Shishi_asn1 * ticket)
 {
-  unsigned char buf[BUFSIZ];
-  unsigned char format[BUFSIZ];
-  int buflen;
+  char *buf;
+  char *format;
+  size_t buflen;
   int res;
   int i, n;
 
@@ -389,31 +389,31 @@ shishi_kdcrep_get_ticket (Shishi * handle,
   if (!*ticket)
     return SHISHI_ASN1_ERROR;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, kdcrep, "ticket.tkt-vno", buf, &buflen);
+  res = shishi_asn1_read2 (handle, kdcrep, "ticket.tkt-vno", &buf, &buflen);
   if (res != SHISHI_OK)
     goto error;
 
   res = shishi_asn1_write (handle, *ticket, "tkt-vno", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     goto error;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, kdcrep, "ticket.realm", buf, &buflen);
+  res = shishi_asn1_read2 (handle, kdcrep, "ticket.realm", &buf, &buflen);
   if (res != SHISHI_OK)
     goto error;
 
   res = shishi_asn1_write (handle, *ticket, "realm", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     goto error;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, kdcrep, "ticket.sname.name-type",
-			  buf, &buflen);
+  res = shishi_asn1_read2 (handle, kdcrep, "ticket.sname.name-type",
+			   &buf, &buflen);
   if (res != SHISHI_OK)
     goto error;
 
   res = shishi_asn1_write (handle, *ticket, "sname.name-type", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     goto error;
 
@@ -429,48 +429,52 @@ shishi_kdcrep_get_ticket (Shishi * handle,
       if (res != SHISHI_OK)
 	goto error;
 
-      sprintf (format, "ticket.sname.name-string.?%d", i);
-      buflen = BUFSIZ;
-      res = shishi_asn1_read (handle, kdcrep, format, buf, &buflen);
+      asprintf (&format, "ticket.sname.name-string.?%d", i);
+      res = shishi_asn1_read2 (handle, kdcrep, format, &buf, &buflen);
+      free (format);
       if (res != SHISHI_OK)
 	goto error;
 
-      sprintf (format, "sname.name-string.?%d", i);
+      asprintf (&format, "sname.name-string.?%d", i);
       res = shishi_asn1_write (handle, *ticket, format, buf, buflen);
+      free (format);
+      free (buf);
       if (res != SHISHI_OK)
 	goto error;
     }
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, kdcrep, "ticket.enc-part.etype",
-			  buf, &buflen);
+  res = shishi_asn1_read2 (handle, kdcrep, "ticket.enc-part.etype",
+			   &buf, &buflen);
   if (res != SHISHI_OK)
     goto error;
 
   res = shishi_asn1_write (handle, *ticket, "enc-part.etype", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     goto error;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, kdcrep, "ticket.enc-part.kvno",
-			  buf, &buflen);
+  res = shishi_asn1_read2 (handle, kdcrep, "ticket.enc-part.kvno",
+			   &buf, &buflen);
   if (res != SHISHI_OK && res != SHISHI_ASN1_NO_ELEMENT)
     goto error;
 
   if (res == SHISHI_ASN1_NO_ELEMENT)
     res = shishi_asn1_write (handle, *ticket, "enc-part.kvno", NULL, 0);
   else
-    res = shishi_asn1_write (handle, *ticket, "enc-part.kvno", buf, buflen);
+    {
+      res = shishi_asn1_write (handle, *ticket, "enc-part.kvno", buf, buflen);
+      free (buf);
+    }
   if (res != SHISHI_OK)
     goto error;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, kdcrep, "ticket.enc-part.cipher",
-			  buf, &buflen);
+  res = shishi_asn1_read2 (handle, kdcrep, "ticket.enc-part.cipher",
+			   &buf, &buflen);
   if (res != SHISHI_OK)
     goto error;
 
   res = shishi_asn1_write (handle, *ticket, "enc-part.cipher", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     goto error;
 
@@ -496,36 +500,36 @@ shishi_kdcrep_set_ticket (Shishi * handle, Shishi_asn1 kdcrep,
 			  Shishi_asn1 ticket)
 {
   int res = SHISHI_OK;
-  unsigned char format[BUFSIZ];
-  unsigned char buf[BUFSIZ];
-  int buflen;
+  char *format;
+  char *buf;
+  size_t buflen;
   int i, n;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "tkt-vno", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "tkt-vno", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, kdcrep, "ticket.tkt-vno", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "realm", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "realm", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, kdcrep, "ticket.realm", buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "sname.name-type", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "sname.name-type", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, kdcrep, "ticket.sname.name-type",
 			   buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
@@ -541,47 +545,49 @@ shishi_kdcrep_set_ticket (Shishi * handle, Shishi_asn1 kdcrep,
       if (res != SHISHI_OK)
 	return res;
 
-      sprintf (format, "sname.name-string.?%d", i);
-
-      buflen = BUFSIZ;
-      res = shishi_asn1_read (handle, ticket, format, buf, &buflen);
+      asprintf (&format, "sname.name-string.?%d", i);
+      res = shishi_asn1_read2 (handle, ticket, format, &buf, &buflen);
+      free (format);
       if (res != SHISHI_OK)
 	return res;
 
-      sprintf (format, "ticket.sname.name-string.?%d", i);
-
+      asprintf (&format, "ticket.sname.name-string.?%d", i);
       res = shishi_asn1_write (handle, kdcrep, format, buf, buflen);
+      free (format);
+      free (buf);
       if (res != SHISHI_OK)
 	return res;
     }
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "enc-part.etype", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "enc-part.etype", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, kdcrep, "ticket.enc-part.etype",
 			   buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "enc-part.kvno", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "enc-part.kvno", &buf, &buflen);
   if (res != SHISHI_OK)
     res = shishi_asn1_write (handle, kdcrep, "ticket.enc-part.kvno", NULL, 0);
   else
-    res = shishi_asn1_write (handle, kdcrep, "ticket.enc-part.kvno",
-			     buf, buflen);
+    {
+      res = shishi_asn1_write (handle, kdcrep, "ticket.enc-part.kvno",
+			       buf, buflen);
+      free (buf);
+    }
   if (res != SHISHI_OK)
     return res;
 
-  buflen = BUFSIZ;
-  res = shishi_asn1_read (handle, ticket, "enc-part.cipher", buf, &buflen);
+  res = shishi_asn1_read2 (handle, ticket, "enc-part.cipher", &buf, &buflen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_asn1_write (handle, kdcrep, "ticket.enc-part.cipher",
 			   buf, buflen);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
@@ -699,8 +705,8 @@ shishi_kdcrep_decrypt (Shishi * handle,
   int i;
   char *buf;
   size_t buflen;
-  unsigned char cipher[BUFSIZ];
-  int cipherlen;
+  char *cipher;
+  size_t cipherlen;
   int etype;
 
   res = shishi_kdcrep_get_enc_part_etype (handle, kdcrep, &etype);
@@ -710,14 +716,14 @@ shishi_kdcrep_decrypt (Shishi * handle,
   if (etype != shishi_key_type (key))
     return SHISHI_KDCREP_BAD_KEYTYPE;
 
-  cipherlen = BUFSIZ;
-  res = shishi_asn1_field (handle, kdcrep, cipher, &cipherlen,
-			   "enc-part.cipher");
+  res = shishi_asn1_read2 (handle, kdcrep, "enc-part.cipher",
+			   &cipher, &cipherlen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_decrypt (handle, key, keyusage,
 			cipher, cipherlen, &buf, &buflen);
+  free (cipher);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle,
