@@ -138,7 +138,7 @@ error:
 }
 
 /**
- * shishi_as_req:
+ * shishi_asreq:
  * @handle: shishi handle as allocated by shishi_init().
  *
  * This function creates a new AS-REQ, populated with some default
@@ -153,7 +153,7 @@ shishi_asreq (Shishi * handle)
 }
 
 /**
- * shishi_tgs_req:
+ * shishi_tgsreq:
  * @handle: shishi handle as allocated by shishi_init().
  *
  * This function creates a new TGS-REQ, populated with some default
@@ -388,8 +388,8 @@ int
 shishi_kdcreq_realm_get (Shishi * handle, Shishi_asn1 kdcreq,
 			 char *realm, int *realmlen)
 {
-  return shishi_asn1_optional_field (handle, kdcreq, realm, realmlen,
-				     "req-body.realm");
+  return shishi_asn1_read_optional (handle, kdcreq, "req-body.realm",
+				    realm, realmlen);
 }
 
 /**
@@ -649,8 +649,7 @@ shishi_kdcreq_add_padata (Shishi * handle,
 			  Shishi_asn1 kdcreq,
 			  int padatatype, char *data, int datalen)
 {
-  char format[BUFSIZ];
-  char buf[BUFSIZ];
+  char *format;
   int res;
   int i;
 
@@ -662,14 +661,15 @@ shishi_kdcreq_add_padata (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  sprintf (format, "padata.?%d.padata-value", i);
+  asprintf (&format, "padata.?%d.padata-value", i);
   res = shishi_asn1_write (handle, kdcreq, format, data, datalen);
+  free (format);
   if (res != SHISHI_OK)
     return res;
 
-  sprintf (buf, "%d", padatatype);
-  sprintf (format, "padata.?%d.padata-type", i);
-  res = shishi_asn1_write (handle, kdcreq, format, buf, 0);
+  asprintf (&format, "padata.?%d.padata-type", i);
+  res = shishi_asn1_write_uint32 (handle, kdcreq, format, padatatype);
+  free (format);
   if (res != SHISHI_OK)
     return res;
 
@@ -717,23 +717,12 @@ shishi_kdcreq_add_padata_tgs (Shishi * handle,
 int
 shishi_kdcreq_build (Shishi * handle, Shishi_asn1 kdcreq)
 {
-  char buffer[BUFSIZ];		/* XXX dynamically allocate this */
-  int buflen;
   int res;
 
   if (VERBOSE (handle))
     printf ("Building KDC-REQ...\n");
 
-  buflen = sizeof(buffer);
-  res = shishi_asn1_empty_field (handle, kdcreq, buffer, &buflen,
-				 "req-body.rtime");
-  if (res != SHISHI_OK)
-    {
-      shishi_error_printf (handle, "Could not read rtime\n");
-      return res;
-    }
-
-  if (buflen == 0)
+  if (shishi_asn1_read_empty_p (handle, kdcreq, "req-body.rtime"))
     {
       res = shishi_asn1_write (handle, kdcreq, "req-body.rtime", NULL, 0);
       if (res != SHISHI_OK)
@@ -743,16 +732,7 @@ shishi_kdcreq_build (Shishi * handle, Shishi_asn1 kdcreq)
 	}
     }
 
-  buflen = sizeof(buffer);
-  res = shishi_asn1_empty_field (handle, kdcreq, buffer, &buflen,
-				 "req-body.from");
-  if (res != SHISHI_OK)
-    {
-      shishi_error_printf (handle, "Could not read from\n");
-      return res;
-    }
-
-  if (buflen == 0)
+  if (shishi_asn1_read_empty_p (handle, kdcreq, "req-body.from"))
     {
       res = shishi_asn1_write (handle, kdcreq, "req-body.from", NULL, 0);
       if (res != SHISHI_OK)
