@@ -44,7 +44,7 @@ shishi_safe (Shishi * handle, Shishi_safe ** safe)
   Shishi_safe *lsafe;
   struct timeval tv;
   struct timezone tz;
-  char usec[BUFSIZ];
+  char *usec;
   int rc;
 
   *safe = malloc (sizeof (**safe));
@@ -76,8 +76,9 @@ shishi_safe (Shishi * handle, Shishi_safe ** safe)
     return rc;
 
   gettimeofday (&tv, &tz);
-  sprintf (usec, "%ld", tv.tv_usec % 1000000);
+  asprintf (&usec, "%ld", tv.tv_usec % 1000000);
   rc = shishi_asn1_write (handle, lsafe->safe, "safe-body.usec", usec, 0);
+  free (usec);
   if (rc != SHISHI_OK)
     return rc;
 
@@ -104,7 +105,7 @@ shishi_safe (Shishi * handle, Shishi_safe ** safe)
 
 /**
  * shishi_safe_key:
- * @ap: structure that holds information about SAFE exchange
+ * @safe: structure that holds information about SAFE exchange
  *
  * Return value: Returns the key used in the SAFE exchange, or NULL if
  *               not yet set or an error occured.
@@ -130,7 +131,7 @@ shishi_safe_key_set (Shishi_safe * safe, Shishi_key * key)
 
 /**
  * shishi_safe_safe:
- * @ap: structure that holds information about SAFE exchange
+ * @safe: structure that holds information about SAFE exchange
  *
  * Return value: Returns the ASN.1 safe in the SAFE exchange, or NULL if
  *               not yet set or an error occured.
@@ -144,7 +145,7 @@ shishi_safe_safe (Shishi_safe * safe)
 /**
  * shishi_safe_safe_set:
  * @safe: structure that holds information about SAFE exchange
- * @safe: KRB-SAFE to store in SAFE exchange.
+ * @asn1safe: KRB-SAFE to store in SAFE exchange.
  *
  * Set the KRB-SAFE in the SAFE exchange.
  **/
@@ -389,7 +390,7 @@ shishi_safe_cksum (Shishi * handle,
   if (res != SHISHI_OK)
     return res;
 
-  res = shishi_asn1_field (handle, safe, cksum, cksumlen, "cksum.checksum");
+  res = shishi_asn1_read (handle, safe, "cksum.checksum", cksum, cksumlen);
   if (res != SHISHI_OK)
     return res;
 
