@@ -25,7 +25,7 @@ int
 shishi_ticket_realm_get (Shishi * handle,
 			 Shishi_asn1 ticket, char *realm, int *realmlen)
 {
-  return shishi_asn1_field (handle, ticket, realm, realmlen, "realm");
+  return shishi_asn1_read (handle, ticket, "realm", realm, realmlen);
 }
 
 /**
@@ -77,12 +77,12 @@ shishi_ticket_sname_set (Shishi * handle,
 			 Shishi_name_type name_type, char *sname[])
 {
   int res = SHISHI_OK;
-  char buf[BUFSIZ];
+  char *buf;
   int i;
 
-  sprintf (buf, "%d", name_type);
-
+  asprintf (&buf, "%d", name_type);
   res = shishi_asn1_write (handle, ticket, "sname.name-type", buf, 0);
+  free (buf);
   if (res != SHISHI_OK)
     return res;
 
@@ -97,8 +97,9 @@ shishi_ticket_sname_set (Shishi * handle,
       if (res != SHISHI_OK)
 	return res;
 
-      sprintf (buf, "sname.name-string.?%d", i);
+      asprintf (&buf, "sname.name-string.?%d", i);
       res = shishi_asn1_write (handle, ticket, buf, sname[i - 1], 0);
+      free (buf);
       if (res != SHISHI_OK)
 	return res;
 
@@ -175,7 +176,7 @@ shishi_ticket_srealmserver_set (Shishi * handle,
 /**
  * shishi_ticket_get_enc_part_etype:
  * @handle: shishi handle as allocated by shishi_init().
- * @kdcrep: Ticket variable to get value from.
+ * @ticket: Ticket variable to get value from.
  * @etype: output variable that holds the value.
  *
  * Extract Ticket.enc-part.etype.
@@ -202,7 +203,7 @@ shishi_ticket_decrypt (Shishi * handle,
   int i;
   char *buf;
   size_t buflen;
-  unsigned char cipher[BUFSIZ];
+  char *cipher;
   size_t cipherlen;
   int etype;
 
@@ -213,15 +214,14 @@ shishi_ticket_decrypt (Shishi * handle,
   if (etype != shishi_key_type (key))
     return SHISHI_TICKET_BAD_KEYTYPE;
 
-  cipherlen = BUFSIZ;
-  res = shishi_asn1_field (handle, ticket, cipher, &cipherlen,
-			   "enc-part.cipher");
+  res = shishi_asn1_read2 (handle, ticket, "enc-part.cipher",
+			   &cipher, &cipherlen);
   if (res != SHISHI_OK)
     return res;
 
   res = shishi_decrypt (handle, key, SHISHI_KEYUSAGE_ENCTICKETPART,
 			cipher, cipherlen, &buf, &buflen);
-
+  free (cipher);
   if (res != SHISHI_OK)
     {
       shishi_error_printf (handle,
@@ -274,7 +274,6 @@ shishi_ticket_set_enc_part (Shishi * handle,
 			    Shishi_asn1 ticket,
 			    int etype, int kvno, char *buf, size_t buflen)
 {
-  char *format;
   int res = SHISHI_OK;
 
   res = shishi_asn1_write (handle, ticket, "enc-part.cipher", buf, buflen);
